/*
 * Copyright 2007 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xbib.files.ftp.mock.stub.command;

import java.util.logging.Level;
import org.xbib.files.ftp.mock.core.command.Command;
import org.xbib.files.ftp.mock.core.command.InvocationRecord;
import org.xbib.files.ftp.mock.core.session.Session;

/**
 * Abstract superclass for CommandHandler for commands that store a file. Send back two replies on the
 * control connection: a reply code of 150 and another of 226.
 *
 * <p>Each invocation record stored by this CommandHandler includes the following data element key/values:
 * <ul>
 * <li>{@link #FILE_CONTENTS_KEY} ("fileContents") - the file contents (<code>byte[]</code>) sent on the data connection
 * </ul>
 *
 * @author Chris Mair
 */
public abstract class AbstractStorCommandHandler extends AbstractStubDataCommandHandler {

    public static final String PATHNAME_KEY = "pathname";
    public static final String FILE_CONTENTS_KEY = "filecontents";

    /**
     * @see AbstractStubDataCommandHandler#processData(Command, Session, InvocationRecord)
     */
    protected void processData(Command command, Session session, InvocationRecord invocationRecord) {
        byte[] data = session.readData();
        LOG.log(Level.FINE, "Received " + data.length + " bytes");
        LOG.log(Level.FINE, "Received data [" + new String(data) + "]");
        invocationRecord.set(FILE_CONTENTS_KEY, data);
    }

}