/*
 * Copyright 2007 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xbib.files.ftp.mock.test.stub.command;

import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.xbib.files.ftp.mock.core.command.Command;
import org.xbib.files.ftp.mock.core.command.CommandNames;
import org.xbib.files.ftp.mock.core.command.ReplyCodes;
import org.xbib.files.ftp.mock.stub.command.TypeCommandHandler;
import org.xbib.files.ftp.mock.test.core.command.AbstractCommandHandlerTestCase;

/**
 * Tests for the TypeCommandHandler class
 * 
 * @author Chris Mair
 */
class TypeCommandHandlerTest extends AbstractCommandHandlerTestCase {

    private TypeCommandHandler commandHandler;

    @Test
    void testHandleCommand() throws Exception {
        final Command COMMAND1 = new Command("TYPE", array("A"));
        final Command COMMAND2 = new Command("TYPE", array("B"));
        final Command COMMAND3 = new Command("TYPE", array("L", "8"));

        commandHandler.handleCommand(COMMAND1, session);
        commandHandler.handleCommand(COMMAND2, session);
        commandHandler.handleCommand(COMMAND3, session);

        verify(session, times(3)).sendReply(ReplyCodes.TYPE_OK, replyTextFor(ReplyCodes.TYPE_OK));

        verifyNumberOfInvocations(commandHandler, 3);
        verifyOneDataElement(commandHandler.getInvocation(0), TypeCommandHandler.TYPE_INFO_KEY, new String[] {"A", null});
        verifyOneDataElement(commandHandler.getInvocation(1), TypeCommandHandler.TYPE_INFO_KEY, new String[] {"B", null});
        verifyOneDataElement(commandHandler.getInvocation(2), TypeCommandHandler.TYPE_INFO_KEY, new String[] {"L", "8"});
    }
    
    @Test
    void testHandleCommand_MissingTypeParameter() throws Exception {
        testHandleCommand_InvalidParameters(commandHandler, CommandNames.TYPE, EMPTY);
    }

    @BeforeEach
    void setUp() throws Exception {
        commandHandler = new TypeCommandHandler();
        commandHandler.setReplyTextBundle(replyTextBundle);
    }

}
