package org.apache.sshd.fs.test;

import java.io.InputStream;
import java.nio.file.Files;
import org.apache.sshd.client.ClientBuilder;
import org.apache.sshd.client.SshClient;
import org.apache.sshd.fs.SftpFileSystem;
import org.apache.sshd.fs.SftpFileSystemProvider;
import org.junit.jupiter.api.Test;
import java.net.URI;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.security.KeyPair;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.stream.Stream;

import org.xbib.net.security.PrivateKeyReader;

import static org.junit.jupiter.api.Assertions.assertTrue;

public class SftpWithPrivateKeyReaderTest {

    private static final Logger logger = Logger.getLogger(SftpWithPrivateKeyReaderTest.class.getName());

    @Test
    public void testXbib() throws Exception {
        Map<String, String> env = new HashMap<>();
        env.put("username", "joerg");
        URI uri = URI.create("sftp://xbib.org");
        Path privateKeyPath = Paths.get(System.getProperty("user.home") + "/.ssh/id_ed25519");
        PrivateKeyReader privateKeyReader = new PrivateKeyReader();
        try (InputStream inputStream = Files.newInputStream(privateKeyPath);
             SshClient sshClient = ClientBuilder.builder().build()) {
            KeyPair keyPair = privateKeyReader.readKeyPair(inputStream, null);
            sshClient.addPublicKeyIdentity(keyPair);
            sshClient.setNioWorkers(1);
            sshClient.start();
            SftpFileSystem fileSystem = new SftpFileSystemProvider(sshClient).newFileSystem(uri, env);
            assertTrue(Files.exists(fileSystem.getDefaultDir()));
            try (Stream<Path> stream = Files.list(fileSystem.getDefaultDir())) {
                stream.forEach(p -> logger.log(Level.INFO, "p = " + p));
            }
            fileSystem.close();
            sshClient.stop();
        }
    }

    @Test
    public void testDionysos() throws Exception {
        Map<String, String> env = new HashMap<>();
        env.put("username", "joerg");
        URI uri = URI.create("sftp://dionysos");
        Path privateKeyPath = Paths.get(System.getProperty("user.home") + "/.ssh/id_ed25519");
        PrivateKeyReader privateKeyReader = new PrivateKeyReader();
        try (InputStream inputStream = Files.newInputStream(privateKeyPath);
             SshClient sshClient = ClientBuilder.builder().build()) {
            KeyPair keyPair = privateKeyReader.readKeyPair(inputStream, null);
            sshClient.addPublicKeyIdentity(keyPair);
            sshClient.setNioWorkers(1);
            sshClient.start();
            SftpFileSystem fileSystem = new SftpFileSystemProvider(sshClient).newFileSystem(uri, env);
            assertTrue(Files.exists(fileSystem.getDefaultDir()));
            try (Stream<Path> stream = Files.list(fileSystem.getDefaultDir())) {
                stream.forEach(p -> logger.log(Level.INFO, "p = " + p));
            }
            fileSystem.close();
            sshClient.stop();
        }
    }

}
