package org.apache.sshd.common.util.security.edec;

import java.security.KeyFactory;
import java.security.KeyPairGenerator;
import java.security.Provider;
import java.security.Security;
import java.security.Signature;
import java.util.Objects;
import org.apache.sshd.common.util.security.AbstractSecurityProviderRegistrar;

public class EdECSecurityProviderRegistrar extends AbstractSecurityProviderRegistrar {

    public EdECSecurityProviderRegistrar() {
        super("Ed25519");
    }

    @Override
    public boolean isEnabled() {
        return super.isEnabled();
    }

    @Override
    public Provider getSecurityProvider() {
        return Security.getProvider("SunJCE");
    }

    @Override
    public boolean isSecurityEntitySupported(Class<?> entityType, String name) {
        if (!isSupported()) {
            return false;
        }
        if (KeyPairGenerator.class.isAssignableFrom(entityType) || KeyFactory.class.isAssignableFrom(entityType)) {
            return Objects.compare(name, getName(), String.CASE_INSENSITIVE_ORDER) == 0;
        } else if (Signature.class.isAssignableFrom(entityType)) {
            return Objects.compare("NONEwithEdDSA", name, String.CASE_INSENSITIVE_ORDER) == 0;
        } else {
            return false;
        }
    }

    @Override
    public boolean isSupported() {
        return true;
    }
}
